=======
History
=======

0.1.0 (2023-02-24)
------------------

* First release on PyPI.

0.1.4 (2023-03-9)
------------------

* Fixed pairwise correlations threshold for multicollinearity assumption testing (0.3 -> 0.7)
* Fixed partial regression plots fixed figure size
* Added titles to diagnostic plots
* Fixed the VIF to match with SPSS output by adding the constant to X

0.1.5 (2023-04-6)
------------------

* Added standardised beta coefficients to model output
* Added partial and semi-partial correlations (unique variance) to model output
* Fixed F-change degrees of freedom calculation
* Fixed F-change p-value calculation

0.2.0 (2024-03-2)
------------------

* Overall project restructuring for optimisation